@@ -10,6 +10,7 @@ import pymol._gui
 from .pymol_gl_widget import PyMOLGLWidget
 from pymol.Qt import QtGui, QtCore
 from pymol.Qt import QtWidgets
+from pymol.Qt.utils import PopupOnException
 
 Qt = QtCore.Qt
 
@@ -40,7 +41,7 @@ def undoablemethod(sele):
 
 class ActionWizard(Wizard):
 
-    def __init__(self,_self):
+    def __init__(self, _self=pymol.cmd):
         Wizard.__init__(self,_self)
         self.actionHash = str(self.__class__)
 
@@ -50,7 +51,7 @@ class ActionWizard(Wizard):
     def activateOrDismiss(self):
         activate_flag = 1
         cur_wiz = self.cmd.get_wizard()
-        if cur_wiz != None:
+        if cur_wiz is not None:
             if cur_wiz.__class__ == self.__class__:
                 if cur_wiz.actionHash == self.actionHash:
                     activate_flag = 0
@@ -90,7 +91,7 @@ class ActionWizard(Wizard):
 
 class CleanWizard(ActionWizard):
 
-    def __init__(self,_self):
+    def __init__(self, _self=pymol.cmd):
         self.clean_obj = None
         ActionWizard.__init__(self,_self)
 
@@ -101,7 +102,7 @@ class CleanWizard(ActionWizard):
                 self.cmd.unpick()
                 self.cmd.set_wizard()
                 self.cmd.refresh_wizard()
-                self.cmd.do("_ cmd.clean('%s',message='''Cleaning %s...''',async=1)"%(active_sele,obj_list[0]))
+                self.cmd.do("_ cmd.clean('%s',message='''Cleaning %s...''',async_=1)"%(active_sele,obj_list[0]))
 
     def do_pick(self, bondFlag):
         if active_sele in self.cmd.get_names("selections"):
@@ -135,7 +136,7 @@ class CleanWizard(ActionWizard):
 
 class SculptWizard(ActionWizard):
 
-    def __init__(self,_self):
+    def __init__(self, _self=pymol.cmd):
         ActionWizard.__init__(self,_self)
         self.sculpt_object = None
 
@@ -157,7 +158,7 @@ class SculptWizard(ActionWizard):
                 print("Error: cannot sculpt more than one object at a time")
 
     def sculpt_deactivate(self):
-        if ((self.sculpt_object != None) and
+        if ((self.sculpt_object is not None) and
             self.sculpt_object in self.cmd.get_names()):
             self.cmd.set("sculpt_vdw_vis_mode","0",self.sculpt_object)
             self.cmd.sculpt_iterate(self.sculpt_object,self.cmd.get_state(),0)
@@ -167,7 +168,7 @@ class SculptWizard(ActionWizard):
             self.cmd.refresh_wizard()
 
     def do_pick(self, bondFlag):
-        if self.sculpt_object == None:
+        if self.sculpt_object is None:
             self.cmd.select(active_sele, "byobj pk1")
             self.sculpt_activate()
         else:
@@ -179,7 +180,7 @@ class SculptWizard(ActionWizard):
                 self.sculpt_activate()
 
     def get_prompt(self):
-        if self.sculpt_object == None:
+        if self.sculpt_object is None:
             return ["Pick object to sculpt..."]
         else:
             return ["Sculpting %s..."%self.sculpt_object]
@@ -229,7 +230,7 @@ class SculptWizard(ActionWizard):
 
 class RepeatableActionWizard(ActionWizard):
 
-    def __init__(self,_self):
+    def __init__(self, _self=pymol.cmd):
         ActionWizard.__init__(self,_self)
         self.repeating = 0
 
@@ -243,7 +244,7 @@ class RepeatableActionWizard(ActionWizard):
     def activateRepeatOrDismiss(self):
         activate_flag = 1
         cur_wiz = self.cmd.get_wizard()
-        if cur_wiz != None:
+        if cur_wiz is not None:
             if cur_wiz.__class__ == self.__class__:
                 if cur_wiz.actionHash == self.actionHash:
                     if cur_wiz.getRepeating():
@@ -303,7 +304,7 @@ class ReplaceWizard(RepeatableActionWizard):
 
 class AttachWizard(RepeatableActionWizard):
 
-    def __init__(self,_self):
+    def __init__(self, _self=pymol.cmd):
         RepeatableActionWizard.__init__(self,_self)
         self.mode = 0
 
@@ -374,9 +375,18 @@ class AttachWizard(RepeatableActionWizard):
 
 class AminoAcidWizard(RepeatableActionWizard):
 
-    def __init__(self,_self):
+    def __init__(self, _self=pymol.cmd, ss=-1):
         RepeatableActionWizard.__init__(self,_self)
         self.mode = 0
+        self.setSecondaryStructure(ss)
+
+    def setSecondaryStructure(self, ss):
+        self._secondary_structure = ss
+
+    def attach_monomer(self, objectname=""):
+         editor.attach_amino_acid("?pk1", self.aminoAcid, object=objectname,
+                ss=self._secondary_structure,
+                 _self=self.cmd)
 
     def do_pick(self, bondFlag):
         # since this function can change any position of atoms in a related
@@ -385,7 +395,7 @@ class AminoAcidWizard(RepeatableActionWizard):
             self.cmd.select(active_sele, "bymol pk1")
             try:
                 with undocontext(self.cmd, "bymol ?pk1"):
-                    editor.attach_amino_acid("pk1", self.aminoAcid, _self=self.cmd)
+                    self.attach_monomer(self.aminoAcid)
             except QuietException:
                 fin = -1
         elif self.mode == 1:
@@ -411,7 +421,8 @@ class AminoAcidWizard(RepeatableActionWizard):
             if name not in names:
                 break
             num = num + 1
-        editor.attach_amino_acid("pk1", self.aminoAcid, object=name, _self=self.cmd)
+        self.attach_monomer(self.aminoAcid)
+
         if not self.getRepeating():
             self.actionWizardDone()
 
@@ -502,7 +513,7 @@ class ChargeWizard(RepeatableActionWizard):
 
     @undoablemethod("bymol ?pk1")
     def do_pick(self, bondFlag):
-        self.cmd.select(active_sele, "bymol pk1") 
+        self.cmd.select(active_sele, "bymol pk1")
         self.cmd.alter("pk1","formal_charge=%s" % self.charge)
         self.cmd.h_fill()
         if abs(float(self.charge))>0.0001:
@@ -541,6 +552,7 @@ class ChargeWizard(RepeatableActionWizard):
 
 class InvertWizard(RepeatableActionWizard):
 
+    @PopupOnException.decorator
     def do_pick(self, bondFlag):
         self.cmd.select(active_sele, "bymol pk1")
         picked = collectPicked(self.cmd)
@@ -832,10 +844,10 @@ class AtomFlagWizard(ActionWizard):
     def do_less(self,mode):
         if active_sele in self.cmd.get_names("selections"):
             if mode == 0:
-                self.cmd.flag(self.flag,"(( byobj " + active_sele + 
+                self.cmd.flag(self.flag,"(( byobj " + active_sele +
                               " ) and not flag %d) extend 1"%self.flag,"clear")
             elif mode == 1:
-                self.cmd.flag(self.flag,"byres ((( byobj " + active_sele + 
+                self.cmd.flag(self.flag,"byres ((( byobj " + active_sele +
                               " ) and not flag %d) extend 1)"%self.flag,"clear")
             self.update_display()
 
@@ -1001,8 +1013,8 @@ class _BuilderPanel(QtWidgets.QWidget):
               ("Cl", "Chlorrine", lambda: self.replace("Cl",1,1, "Chlorine")),
               ("Br", "Bromine", lambda: self.replace("Br",1,1, "Bromine")),
               ("I", "Iodine", lambda: self.replace("I",1,1, "Iodine")),
-              ("-CF3", "Trifluoromethane", lambda: self.replace("trifluoromethane",4,0, "trifluoro")),
-              ("-OMe", "Methanol", lambda: self.replace("methanol",5,0, "methoxy")),
+              ("-CF3", "Trifluoromethane", lambda: self.grow("trifluoromethane",4,0, "trifluoro")),
+              ("-OMe", "Methanol", lambda: self.grow("methanol",5,0, "methoxy")),
             ],
             [ ("CH4", "Methyl", lambda: self.grow("methane",1,0,"methyl")),
               ("C=C", "Ethylene", lambda: self.grow("ethylene",4,0,"vinyl")),
@@ -1062,6 +1074,16 @@ class _BuilderPanel(QtWidgets.QWidget):
                 btn.clicked.connect(slot)
                 self.protein_layout.addWidget(btn, row, col)
 
+        lab = QtWidgets.QLabel('Secondary Structure:')
+        lab_cols = 3
+        self.ss_cbox = QtWidgets.QComboBox()
+        self.ss_cbox.addItem("Alpha Helix")
+        self.ss_cbox.addItem("Beta Sheet (Anti-Parallel)")
+        self.ss_cbox.addItem("Beta Sheet (Parallel)")
+        self.protein_layout.addWidget(lab, 2, 0, 1, lab_cols)
+        self.protein_layout.addWidget(self.ss_cbox, 2, lab_cols, 1, 4)
+        self.ss_cbox.currentIndexChanged[int].connect(self.ssIndexChanged)
+
         buttons = [
             [
               ( "@Atoms:", None, None),
@@ -1170,17 +1192,24 @@ class _BuilderPanel(QtWidgets.QWidget):
             ReplaceWizard(_self=self.cmd).toggle(atom,geometry,valence,text)
 
     def attach(self, aa):
+        ss = self.ss_cbox.currentIndex() + 1
         picked = collectPicked(self.cmd)
         if len(picked)==1:
             try:
                 with undocontext(self.cmd, "bymol %s" % picked[0]):
-                    editor.attach_amino_acid(picked[0], aa, _self=self.cmd)
+                    editor.attach_amino_acid(picked[0], aa,
+                            ss=ss, _self=self.cmd)
             except:
                 fin = -1
             self.doZoom()
         else:
             self.cmd.unpick()
-            AminoAcidWizard(_self=self.cmd).toggle(aa)
+            AminoAcidWizard(_self=self.cmd, ss=ss).toggle(aa)
+
+    def ssIndexChanged(self, index):
+        w = self.cmd.get_wizard()
+        if isinstance(w, AminoAcidWizard):
+            w.setSecondaryStructure(index + 1)
 
     def doAutoPick(self, old_atoms=None):
         self.cmd.unpick()
@@ -1193,7 +1222,7 @@ class _BuilderPanel(QtWidgets.QWidget):
             index = new_list.pop()
             try:
                 self.cmd.edit("%s`%d" % index)
-                if self.cmd.get_wizard()!=None:
+                if self.cmd.get_wizard() is not None:
                     self.cmd.do("_ cmd.get_wizard().do_pick(0)")
             except pymol.CmdException:
                 print(" doAutoPick-Error: exception")
@@ -1267,7 +1296,8 @@ class _BuilderPanel(QtWidgets.QWidget):
         else:
             HydrogenWizard(_self=self.cmd).toggle('add')
 
-    def invert(self):
+    @PopupOnException.decorator
+    def invert(self, _=None):
         picked = collectPicked(self.cmd)
         if picked == ["pk1","pk2","pk3"]:
             self.cmd.invert()
@@ -1308,6 +1338,7 @@ class _BuilderPanel(QtWidgets.QWidget):
             "Really delete everything?", QMB.Yes | QMB.No)
         if check == QMB.Yes:
             self.cmd.delete("all")
+            self.cmd.refresh_wizard()
 
     def sculpt(self):
         picked = collectPicked(self.cmd)
@@ -1354,4 +1385,3 @@ def BuilderPanelDocked(parent, *args, **kwargs):
     window.setWidget(widget)
     window.setFloating(True)
     return window
-
