@@ -171,6 +171,11 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
             def mouseDoubleClickEvent(_, event):
                 self.toggle_ext_window_dockable(True)
 
+            _size_hint = QtCore.QSize(options.win_x, options.ext_y)
+
+            def sizeHint(self):
+                return self._size_hint
+
         dockWidgetContents = ExtGuiFrame(self)
         dockWidgetContents.setLayout(extguilayout)
         dockWidgetContents.setObjectName("extgui")
@@ -264,6 +269,19 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
 
             quickbuttonslayout.addLayout(hbox)
 
+        # progress bar
+        hbox = QtWidgets.QHBoxLayout()
+        self.progressbar = QtWidgets.QProgressBar()
+        self.progressbar.setSizePolicy(
+                QtWidgets.QSizePolicy.Minimum,
+                QtWidgets.QSizePolicy.Minimum)
+        hbox.addWidget(self.progressbar)
+        self.abortbutton = QtWidgets.QPushButton('Abort')
+        self.abortbutton.setStyleSheet("background: #FF0000; color: #FFFFFF")
+        self.abortbutton.released.connect(cmd.interrupt)
+        hbox.addWidget(self.abortbutton)
+        quickbuttonslayout.addLayout(hbox)
+
         quickbuttonslayout.addStretch()
         quickbuttons_stretch_index = quickbuttonslayout.count() - 1
 
@@ -707,7 +725,7 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
             if ray:
                 self.cmd.set('opaque_background',
                         not form.input_transparent.isChecked())
-                self.cmd.do('ray %d, %d' % (width, height))
+                self.cmd.do('ray %d, %d, async=1' % (width, height))
             else:
                 self.cmd.do('draw %d, %d' % (width, height))
             form.stack.setCurrentIndex(1)
@@ -782,6 +800,12 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
     def file_save_mov(self):
         self.file_save_mpeg('mov')
 
+    def file_save_stl(self):
+        self._file_save('STL File (*.stl)', 'stl')
+
+    def file_save_gltf(self):
+        self._file_save('GLTF File (*.gltf)', 'gltf')
+
     LOG_FORMATS = [
         'PyMOL Script (*.pml)',
         'Python Script (*.py *.pym)',
@@ -848,7 +872,7 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
         msg = [
             'The PyMOL Molecular Graphics System\n',
             'Version %s' % (self.cmd.get_version()[0]),
-            'Copyright (C) Schrodinger LLC.',
+            u'Copyright (C) Schr\xF6dinger, LLC.',
             'All rights reserved.\n',
             'License information:',
         ]
@@ -880,7 +904,19 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
     def command_set_cursor(self, i):
         return self.lineedit.setCursorPosition(i)
 
+    def update_progress(self):
+        progress = self.cmd.get_progress()
+        if progress >= 0:
+            self.progressbar.setValue(progress * 100)
+            self.progressbar.show()
+            self.abortbutton.show()
+        else:
+            self.progressbar.hide()
+            self.abortbutton.hide()
+
     def update_feedback(self):
+        self.update_progress()
+
         feedback = self.cmd._get_feedback()
         if feedback:
             html = colorprinting.text2html('\n'.join(feedback))
@@ -1081,6 +1117,15 @@ class PyMOLApplication(QtWidgets.QApplication):
         if ev.type() != QtCore.QEvent.FileOpen:
             return False
 
+        # When double clicking a file in Finder, open it in a new instance
+        if not pymol.invocation.options.reuse_helper and pymol.cmd.get_names():
+            window.new_window([ev.file()])
+            return True
+
+        # pymol -I -U
+        if pymol.invocation.options.auto_reinitialize:
+            pymol.cmd.reinitialize()
+
         # PyMOL Show
         if ev.file().endswith('.psw'):
             pymol.cmd.set('presentation')
